summaryrefslogtreecommitdiff
path: root/distrib/mac68k
diff options
context:
space:
mode:
Diffstat (limited to 'distrib/mac68k')
-rw-r--r--distrib/mac68k/inst-common/dot.commonutils7
-rw-r--r--distrib/mac68k/inst-common/list2
-rw-r--r--distrib/mac68k/inst-common/raminst.conf5
-rw-r--r--distrib/mac68k/inst/dot.instutils6
-rw-r--r--distrib/mac68k/inst/install.sh15
5 files changed, 18 insertions, 17 deletions
diff --git a/distrib/mac68k/inst-common/dot.commonutils b/distrib/mac68k/inst-common/dot.commonutils
index 5000223885e..64f840321c8 100644
--- a/distrib/mac68k/inst-common/dot.commonutils
+++ b/distrib/mac68k/inst-common/dot.commonutils
@@ -1,4 +1,4 @@
-# $OpenBSD: dot.commonutils,v 1.2 1996/04/25 21:28:42 niklas Exp $
+#
# $NetBSD: dot.commonutils,v 1.1 1995/07/18 04:13:18 briggs Exp $
#
# Copyright (c) 1994 Christopher G. Demetriou
@@ -28,10 +28,11 @@
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
# THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+#
-# Installation utilites (functions), to get OpenBSD installed on
+# Installation utilites (functions), to get NetBSD installed on
# the hard disk. These are meant to be invoked from the shell prompt,
-# by people installing OpenBSD.
+# by people installing NetBSD.
Set_tmp_dir()
{
diff --git a/distrib/mac68k/inst-common/list b/distrib/mac68k/inst-common/list
index 657196aa566..fa18961bb4f 100644
--- a/distrib/mac68k/inst-common/list
+++ b/distrib/mac68k/inst-common/list
@@ -21,7 +21,6 @@ LINK raminst bin/sh
LINK raminst bin/-sh
LINK raminst bin/stty
LINK raminst bin/sync
-LINK raminst bin/tar
LINK raminst bin/test
LINK raminst bin/[
LINK raminst sbin/disklabel
@@ -49,6 +48,7 @@ LINK raminst usr/bin/more
LINK raminst usr/bin/printf
LINK raminst usr/bin/sed
LINK raminst usr/bin/strings
+LINK raminst usr/bin/tar
LINK raminst usr/bin/tip
LINK raminst usr/sbin/chown
LINK raminst usr/sbin/chroot
diff --git a/distrib/mac68k/inst-common/raminst.conf b/distrib/mac68k/inst-common/raminst.conf
index 5e482bf614a..55c01cc0543 100644
--- a/distrib/mac68k/inst-common/raminst.conf
+++ b/distrib/mac68k/inst-common/raminst.conf
@@ -9,13 +9,12 @@ srcdirs /usr/src/gnu/usr.bin
progs cat chmod chown chroot cp dd df disklabel ed expr fsck ftp
progs gzip ifconfig init halt ln ls mkdir mknod more mount mount_cd9660
-progs mount_ffs mount_msdos mount_nfs mv newfs pax printf pwd reboot rm route
-progs sed sh shutdown slattach strings stty sync test tip umount update
+progs mount_ffs mount_msdos mount_nfs mv newfs printf pwd reboot rm route
+progs sed sh shutdown slattach strings stty sync tar test tip umount update
ln chown chgrp
ln gzip gzcat gunzip
ln sh -sh # init invokes the shell this way
-ln pax tar
ln test [
ln mount_ffs ffs
diff --git a/distrib/mac68k/inst/dot.instutils b/distrib/mac68k/inst/dot.instutils
index 5ad7d1ff52e..94a55659fe5 100644
--- a/distrib/mac68k/inst/dot.instutils
+++ b/distrib/mac68k/inst/dot.instutils
@@ -1,4 +1,4 @@
-# $OpenBSD: dot.instutils,v 1.2 1996/04/25 21:28:35 niklas Exp $
+#
# $NetBSD: dot.instutils,v 1.1 1995/07/18 04:13:08 briggs Exp $
#
# Copyright (c) 1994 Christopher G. Demetriou
@@ -30,9 +30,9 @@
# THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#
-# Installation configuration utilites (functions), to get OpenBSD configured
+# Installation configuration utilites (functions), to get NetBSD configured
# reasonably once it is installed on the hard disk. These are meant to be
-# invoked from the shell prompt, by people installing OpenBSD.
+# invoked from the shell prompt, by people installing NetBSD.
Configure()
{
diff --git a/distrib/mac68k/inst/install.sh b/distrib/mac68k/inst/install.sh
index 374038d661f..1eec1d88717 100644
--- a/distrib/mac68k/inst/install.sh
+++ b/distrib/mac68k/inst/install.sh
@@ -1,5 +1,5 @@
#!/bin/sh
-# $OpenBSD: install.sh,v 1.2 1996/04/25 21:28:38 niklas Exp $
+#
# $NetBSD: install.sh,v 1.1 1995/07/18 04:13:10 briggs Exp $
#
# Copyright (c) 1994 Christopher G. Demetriou
@@ -29,8 +29,9 @@
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
# THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
# OpenBSD installation script.
# In a perfect world, this would be a nice C program, with a reasonable
# user interface.
@@ -94,9 +95,9 @@ prepdrive() {
esac
}
-echo "Welcome to the OpenBSD ${VERSION} installation program."
+echo "Welcome to the NetBSD ${VERSION} installation program."
echo ""
-echo "This program is designed to help you put OpenBSD on your hard disk,"
+echo "This program is designed to help you put NetBSD on your hard disk,"
echo "in a simple and rational way. Its main objective is to format,"
echo "mount and create an fstab for your root (/) and user (/usr)"
echo "partitions."
@@ -153,7 +154,7 @@ echo ""
echo "THIS IS YOUR LAST CHANCE!!!"
echo ""
echo "(answering yes will format your root partition on $rdev)"
-echo -n "Are you SURE you want OpenBSD installed on your hard drive? (yes/no) "
+echo -n "Are you SURE you want NetBSD installed on your hard drive? (yes/no) "
answer=""
while [ "$answer" = "" ]; do
getresp
@@ -257,11 +258,11 @@ echo " done."
echo ""
echo ""
echo "OK! The preliminary work of setting up your disk is now complete,"
-echo "and you can install the actual OpenBSD software."
+echo "and you can install the actual NetBSD software."
echo ""
echo "Right now, your root is mounted on /mnt and your usr on /mnt/usr."
echo "You should consult the installation notes to determine how to load"
-echo "and install the OpenBSD distribution sets, and how to configure your"
+echo "and install the NetBSD distribution sets, and how to configure your"
echo "system when you are done."
echo ""
echo "GOOD LUCK!"
@@ -29,8 +29,9 @@
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
# THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+#
-# OpenBSD installation script.
+# NetBSD installation script.
# In a perfect world, this would be a nice C program, with a reasonable
# user interface.